@@ -132,13 +132,13 @@ static ConfigItem gp_config_items[] = {
   CONFIG_SECTION (sect_workarounds,         	     	N_ ("Window Manager Workarounds")),
   CONFIG_BOOL (skip_movement_offset,		TRUE,
 	       N_ ("Window manager moves decoration window instead\n"
-		   "(AfterStep, Enlightenment, FVWM, IceWM, SawMill)")),
+		   "(AfterStep, Enlightenment, FVWM, IceWM, Sawmill)")),
   CONFIG_BOOL (unified_areas,			TRUE,
 	       N_ ("Window manager changes active area on all desktops\n"
-		   "(FVWM, SawMill)")),
-  CONFIG_BOOL (violate_client_msg,			TRUE,
+		   "(FVWM, Sawmill)")),
+  CONFIG_BOOL (violate_client_msg,		FALSE,
 	       N_ ("Window manager expects pager to modify area+desktop properties directly\n"
-		   "(Enlightenment, FVWM, SawMill)")),
+		   "(Enlightenment, FVWM)")),
 };
 static guint  gp_n_config_items = (sizeof (gp_config_items) /
 				   sizeof (gp_config_items[0]));
@@ -334,11 +334,13 @@ gp_save_session (gpointer     func_data,
   for (i = 0; i < gp_n_config_items; i++)
     {
       ConfigItem *item = gp_config_items + i;
-      gchar *path = g_strconcat (section, "/", item->path, NULL);
-      
+      gchar *path;
+
       if (!item->path)					/* page */
 	continue;
-      else if (item->min == -2 && item->max == -2)	/* section */
+
+      path = g_strconcat (section, "/", item->path, NULL);
+      if (item->min == -2 && item->max == -2)		/* section */
 	section = item->path;
       else if (item->min == -1 && item->max == -1)	/* boolean */
 	gnome_config_set_bool (path, GPOINTER_TO_INT (item->value));
