@@ -105,7 +105,7 @@ create_minimized_icon (GdkPixbuf *pixbuf)
 gchar *
 fixup_task_label (TasklistTask *task)
 {
-	gchar *str;
+	gchar *str, *tempstr;
 	gint len, label_len;
 
 	label_len = gdk_string_width (area->style->font,
@@ -116,16 +116,34 @@ fixup_task_label (TasklistTask *task)
 					       "[]");
 
 	if (label_len > task->width - ROW_HEIGHT) {
+		GdkWChar *wstr;
+
 		len = strlen (task->gwmh_task->name);
+		wstr = g_new (GdkWChar, len + 3);
+		len = gdk_mbstowcs (wstr, task->gwmh_task->name, len);
+		if ( len < 0 ) { /* if the conversion is failed */
+			wstr[0] = wstr[1] = wstr[2] = '?'; 
+			wstr[3] = '\0'; /* wcscpy(wstr,"???");*/
+			len = 3;
+			label_len = gdk_text_width_wc(area->style->font,
+                                                      wstr, len);
+			if (label_len <= task->width 
+			    - (Config.show_mini_icons ? 24:6)) {
+				str = gdk_wcstombs(wstr);
+				g_free(wstr);
+				return str;
+			}
+		}
+		wstr[len] = wstr[len+1] = '.';
+		wstr[len+2] = '\0'; /*wcscat(wstr,"..");*/
 		len--;
-		str = g_malloc (len + 4);
-		strcpy (str, task->gwmh_task->name);
-		strcat (str, "..");
+
 		for (; len > 0; len--) {
-			str[len] = '.';
-			str[len + 3] = '\0';
+			wstr[len] = '.';
+			wstr[len + 3] = '\0';
 			
-			label_len = gdk_string_width (area->style->font, str);
+			label_len = gdk_text_width_wc (area->style->font,
+						       wstr, len + 3);
 			
 			if (GWMH_TASK_ICONIFIED (task->gwmh_task))
 				label_len += gdk_string_width (area->style->font,
@@ -133,12 +151,16 @@ fixup_task_label (TasklistTask *task)
 			if (label_len <= task->width - (Config.show_mini_icons ? 24:6))
 				break;
 		}
+		str = gdk_wcstombs (wstr);
+		g_free (wstr);
 	}
 	else
 		str = g_strdup (task->gwmh_task->name);
 
 	if (GWMH_TASK_ICONIFIED (task->gwmh_task)) {
-		str = g_strdup_printf ("[%s]", str);
+		tempstr = g_strdup_printf ("[%s]", str);
+		g_free(str);
+		str = tempstr;
 	}
 
 	return str;
@@ -567,21 +589,33 @@ task_notifier (gpointer func_data, GwmhTask *gwmh_task,
 									   width, height);
 									   
 			task->icon->minimized = create_minimized_icon (task->icon->normal);
+			gdk_pixmap_unref(pixmap);
 		}
 		else {
-
 			task->icon->mask = unknown_icon->mask;
 			task->icon->normal = unknown_icon->normal;
 			task->icon->minimized = unknown_icon->minimized;
+
+			/* ref them so that unref won't kill them when the
+			 * task is destroyed */
+			gdk_bitmap_ref(unknown_icon->mask);
+			gdk_pixbuf_ref(unknown_icon->normal);
+			gdk_pixbuf_ref(unknown_icon->minimized);
 		}
 		tasks = g_list_append (tasks, task);
 	        layout_tasklist ();
 		break;
 	case GWMH_NOTIFY_DESTROY:
 		task = find_gwmh_task (gwmh_task);
-		tasks = g_list_remove (tasks, task);
-		g_free (task);
-		layout_tasklist ();
+		if(task) {
+			tasks = g_list_remove (tasks, task);
+			gdk_bitmap_unref(task->icon->mask);
+			gdk_pixbuf_unref(task->icon->normal);
+			gdk_pixbuf_unref(task->icon->minimized);
+			g_free (task->icon);
+			g_free (task);
+			layout_tasklist ();
+		}
 		break;
 	default:
 		g_print ("Unknown ntype: %d\n", ntype);
@@ -643,7 +677,6 @@ cb_expose_event (GtkWidget *widget, GdkEventExpose *event)
 		       area->allocation.width,
 		       area->allocation.height);
 
-
 	while (temp_tasks) {
 		task = (TasklistTask *)temp_tasks->data;
 		draw_task (task);
@@ -710,6 +743,10 @@ change_size (gboolean layout)
 	switch (applet_widget_get_panel_orient (APPLET_WIDGET (applet))) {
 	case ORIENT_UP:
 	case ORIENT_DOWN:
+		if (Config.horz_fixed)
+			horz_width = Config.horz_width;
+		else
+			horz_width = 4;
 		GTK_HANDLE_BOX (handle)->handle_position = GTK_POS_LEFT;
 		gtk_widget_set_usize (handle, 
 				      DRAG_HANDLE_SIZE + horz_width,
@@ -720,6 +757,10 @@ change_size (gboolean layout)
 		break;
 	case ORIENT_LEFT:
 	case ORIENT_RIGHT:
+		if (Config.vert_fixed)
+			vert_height = Config.vert_height;
+		else
+			vert_height = 4;
 		GTK_HANDLE_BOX (handle)->handle_position = GTK_POS_TOP;
 		gtk_widget_set_usize (handle, 
 				      (Config.follow_panel_size?
@@ -807,8 +848,6 @@ create_applet (void)
 					       _("Properties..."),
 					       (AppletCallbackFunc) cb_properties,
 					       NULL);
-	change_size (TRUE);
-	gtk_widget_show (applet);
 }
 
 gint
@@ -835,6 +874,12 @@ main (gint argc, gchar *argv[])
 	create_applet ();
 
 	read_config ();
+	panel_size = applet_widget_get_panel_pixel_size(APPLET_WIDGET(applet));
+	tasklist_orient = applet_widget_get_panel_orient(APPLET_WIDGET(applet));
+
+	change_size (TRUE);
+
+	gtk_widget_show (applet);
 
 	unknown_icon = g_new (TasklistIcon, 1);
 	/* XXX: why do we need to cast unknown_xpm here,
