@@ -1,4 +1,5 @@
 #include <gnome.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include "authors.h"
 #include "logo.xpm"
 
@@ -15,7 +16,7 @@ GdkFont *font=NULL;
 GdkFont *italicfont=NULL;
 gint y, y_to_wrap_at;
 gint howmuch=0;
-GdkImlibImage *im;
+GdkPixbuf *im;
 GtkWidget *canvas;
 GnomeCanvasItem *image;
 	
@@ -269,9 +270,9 @@ cb_keypress (GtkWidget *widget, GdkEventKey *event)
 	case GDK_E:
 		if (howmuch == 4) {
 			howmuch++;
-			im = gdk_imlib_create_image_from_xpm_data (magick);
+			im = gdk_pixbuf_new_from_xpm_data (magick);
 			gnome_canvas_item_set (image,
-					       "image", im,
+					       "pixbuf", im,
 					       NULL);
 		}
 		else
@@ -421,6 +422,10 @@ main (gint argc, gchar *argv[])
 	GtkWidget *href;
 	
 	gnome_init ("gnome-about","1.0", argc, argv);
+
+	gdk_rgb_init ();
+	gtk_widget_set_default_colormap (gdk_rgb_get_cmap ());
+	gtk_widget_set_default_visual (gdk_rgb_get_visual ());
 	
 	window = gtk_window_new (GTK_WINDOW_DIALOG);
 	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
@@ -448,20 +453,23 @@ main (gint argc, gchar *argv[])
 					       logo_xpm);
 	gtkpixmap = gtk_pixmap_new (logo_pixmap, logo_mask);
 
-	im = gdk_imlib_create_image_from_xpm_data (logo_xpm);
+	im = gdk_pixbuf_new_from_xpm_data (logo_xpm);
 
 	canvas = gnome_canvas_new ();
-	gtk_widget_set_usize (canvas, im->rgb_width, im->rgb_height);
+	gtk_widget_set_usize (canvas,
+			      gdk_pixbuf_get_width (im),
+			      gdk_pixbuf_get_height (im));
 	gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas), 0, 0,
-					im->rgb_width, im->rgb_height);
+					gdk_pixbuf_get_width (im),
+					gdk_pixbuf_get_height (im));
+
 	image = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (canvas)->root),
-				       gnome_canvas_image_get_type (),
-				       "image", im,
+				       gnome_canvas_pixbuf_get_type (),
+				       "pixbuf", im,
 				       "x", 0.0,
 				       "y", 0.0,
-				       "width", (double) im->rgb_width,
-				       "height", (double) im->rgb_height,
-				       "anchor", GTK_ANCHOR_NW,
+				       "width", (double) gdk_pixbuf_get_width (im),
+				       "height", (double) gdk_pixbuf_get_height (im),
 				       NULL);
 	gtk_signal_connect (GTK_OBJECT (image), "destroy",
 			    GTK_SIGNAL_FUNC (free_imlib_image), im);
