@@ -48,7 +48,7 @@
 #define ENVNAME "SESSION_MANAGER"
 
 /* Network ids.  */
-char* ids;
+static char* ids;
 
 /* List of all auth entries.  */
 GSList *auth_entries;
@@ -56,7 +56,7 @@ GSList *auth_entries;
 /* The "sockets" which we listen on */
 IceListenObj *sockets;
 static gint *input_id;
-gint num_sockets;
+static gint num_sockets;
 
 /* File containing the ICE authorization data (usually ~/.ICEauthority) */
 static gchar* authfile;
