@@ -12,6 +12,33 @@
 
 #include "gnome-panel.h"
 
+struct _AppletWidgetPrivate
+{
+	/* CORBA stuff */
+        gpointer                corbadat;
+	
+	/*change freezing*/
+	int			frozen_level;
+
+	gboolean		frozen_got_orient;
+	PanelOrientType		frozen_orient;			
+
+	gboolean		frozen_got_size;
+	int			frozen_size;			
+	
+	gboolean		frozen_got_back;
+	PanelBackType		frozen_back_type;			
+	char 			*frozen_back_pixmap;			
+	GdkColor		frozen_back_color;			
+	
+	gboolean		frozen_got_position;
+	int			frozen_position_x;
+	int			frozen_position_y;
+
+	/* for local case */
+	GtkWidget		*ebox;
+};
+
 /*****************************************************************************
   CORBA STUFF
  *****************************************************************************/
@@ -153,7 +180,7 @@ static gboolean die_on_last = FALSE;
 static GtkPlugClass *parent_class;
 static GtkTooltips *applet_tooltips = NULL;
 
-#define CD(applet) ((CustomAppletServant *)APPLET_WIDGET(applet)->corbadat)
+#define CD(applet) ((CustomAppletServant *)APPLET_WIDGET(applet)->_priv->corbadat)
 
 guint
 applet_widget_get_type ()
@@ -344,9 +371,10 @@ wapplet_widget_init (AppletWidget *applet)
 	g_return_if_fail(applet != NULL);
 	g_return_if_fail(IS_APPLET_WIDGET(applet));
 	
-	applet->corbadat = NULL;
 	applet->orient = ORIENT_UP;
 	applet->size = PIXEL_SIZE_STANDARD;
+	applet->_priv = g_new0(AppletWidgetPrivate, 1);
+	applet->_priv->corbadat = NULL;
 }
 
 static void
@@ -413,6 +441,14 @@ applet_widget_destroy(GtkWidget *w, gpointer data)
 		}
 	}
 
+	if(applet->_priv->ebox && GTK_BIN(applet->_priv->ebox)->child) {
+		GtkWidget *child = GTK_BIN(applet->_priv->ebox)->child;
+		/* disconnect the destroy handler */
+		gtk_signal_disconnect_by_data(GTK_OBJECT(child), applet);
+		gtk_widget_destroy(child);
+	}
+
+
 	if(applet->privcfgpath) {
 		g_free(applet->privcfgpath);
 		g_free(applet->globcfgpath);
@@ -429,14 +465,26 @@ applet_widget_destroy(GtkWidget *w, gpointer data)
 		CORBA_exception_free(&ev);
 	}
 
-	applet_servant_destroy(applet->corbadat);
+	applet_servant_destroy(applet->_priv->corbadat);
 
 	applet_count--;
 
 	if(die_on_last && applet_count == 0)
 		applet_widget_gtk_main_quit();
+
+	g_free(applet->_priv);
 }
 
+/**
+ * applet_widget_abort_load:
+ * @applet: #AppletWidget to work on.
+ *
+ * Description:  Abort the applet loading, once applet has been created, this is
+ * a way to tell the panel to forget about us if we decide we want to quit
+ * before we add the actual applet to the applet-widget.  This is only useful
+ * to abort after #applet_widget_new was called but before #applet_widget_add
+ * is called.
+ **/
 void
 applet_widget_abort_load(AppletWidget *applet)
 {
@@ -446,6 +494,13 @@ applet_widget_abort_load(AppletWidget *applet)
 	CORBA_exception_free(&ev);
 }
 
+/**
+ * applet_widget_remove:
+ * @applet: #AppletWidget to work on.
+ *
+ * Description:  Remove the plug from the panel, this will destroy the applet.
+ * You can only call this once for each applet.
+ **/
 void
 applet_widget_remove(AppletWidget *applet)
 {
@@ -455,13 +510,30 @@ applet_widget_remove(AppletWidget *applet)
 	g_return_if_fail(IS_APPLET_WIDGET(applet));
 
 	CORBA_exception_init(&ev);
-	servant = applet->corbadat;
-	goad_server_unregister(CORBA_OBJECT_NIL, servant->goad_id, "server", &ev);
+	servant = applet->_priv->corbadat;
+	goad_server_unregister(CORBA_OBJECT_NIL, servant->goad_id,
+			       "server", &ev);
 
 	GNOME_PanelSpot_unregister_us(CD(applet)->pspot, &ev);
 	CORBA_exception_free(&ev);
 }
 
+/**
+ * applet_widget_sync_config:
+ * @applet: #AppletWidget to work on.
+ *
+ * Description:  Tell the panel to save our session here (just saves, no
+ * shutdown).  This should be done when you change some of your config and want
+ * the panel to save it's config, you should NOT call this in the session_save
+ * handler as it will result in a locked panel, as it will actually trigger
+ * another session_save signal for you.  However it also asks for a complete
+ * panel save, so you should not do this too often, and only when the user
+ * has changed some preferences and you want to sync them to disk. 
+ * Theoretically you don't even need to do that if you don't mind loosing
+ * settings on a panel crash or when the user kills the session without
+ * logging out properly, since the panel will always save your session when
+ * it exists.
+ **/
 void
 applet_widget_sync_config(AppletWidget *applet)
 {
@@ -541,6 +613,19 @@ gnome_panel_applet_register_callback(GtkWidget *applet,
 	CORBA_exception_free(&ev);
 }
 
+/**
+ * applet_widget_register_callback:
+ * @applet: #AppletWidget to work on.
+ * @name: path to the menu item.
+ * @menutext: text for the menu item.
+ * @func: #AppletCallbacFunc to call when the menu item is activated.
+ * @data: data passed to @func.
+ *
+ * Description:  Adds a menu item to the applet's context menu.  The name
+ * should be a path that is separated by '/' and ends in the name of this
+ * item.  You need to add any submenus with
+ * #applet_widget_register_callback_dir.
+ **/
 void
 applet_widget_register_callback(AppletWidget *applet,
 				const char *name,
@@ -558,6 +643,19 @@ applet_widget_register_callback(AppletWidget *applet,
 					      "",menutext,func,data);
 }
 
+/**
+ * applet_widget_register_stock_callback:
+ * @applet: #AppletWidget to work on.
+ * @name: path to the menu item.
+ * @stock_type: GNOME_STOCK string to use for the pixmap
+ * @menutext: text for the menu item.
+ * @func: #AppletCallbacFunc to call when the menu item is activated.
+ * @data: data passed to @func.
+ *
+ * Description:  Adds a menu item to the applet's context menu with a stock 
+ * GNOME pixmap.  This works almost exactly the same as
+ * #applet_widget_register_callback.
+ **/
 void
 applet_widget_register_stock_callback(AppletWidget *applet,
 				      const char *name,
@@ -577,6 +675,16 @@ applet_widget_register_stock_callback(AppletWidget *applet,
 					      stock_type,menutext,func,data);
 }
 
+
+/**
+ * applet_widget_unregister_callback:
+ * @applet: #AppletWidget to work on.
+ * @name: path to the menu item.
+ *
+ * Description:  Remove a menu item from the applet's context menu.  The
+ * @name should be the full path to the menu item.  This will not remove
+ * any submenus.
+ **/
 void
 applet_widget_unregister_callback(AppletWidget *applet,
 				  const char *name)
@@ -634,6 +742,17 @@ gnome_panel_applet_register_callback_dir(GtkWidget *applet,
 }
 
 
+/**
+ * applet_widget_register_callback_dir:
+ * @applet: #AppletWidget to work on.
+ * @name: path to the menu item.
+ * @menutext: text for the menu item.
+ *
+ * Description:  Adds a submenu to the applet's context menu.  The @name
+ * should be the full path of the new submenu with the name of the new
+ * submenu as the last part of the path.  The @name can, but doesn't
+ * have to be terminated with a '/'.
+ **/
 void
 applet_widget_register_callback_dir(AppletWidget *applet,
 				    const char *name,
@@ -647,6 +766,18 @@ applet_widget_register_callback_dir(AppletWidget *applet,
 	gnome_panel_applet_register_callback_dir (GTK_WIDGET(applet),name,
 						  "",menutext);
 }
+
+
+/**
+ * applet_widget_register_stock_callback_dir:
+ * @applet: #AppletWidget to work on.
+ * @name: path to the menu item.
+ * @stock_type: GNOME_STOCK string to use for the pixmap
+ * @menutext: text for the menu item.
+ *
+ * Description:  Adds a submenu to the applet's context menu with a stock 
+ * GNOME pixmap.  This is similiar to #applet_widget_register_callback_dir.
+ **/
 void
 applet_widget_register_stock_callback_dir(AppletWidget *applet,
 					  const char *name,
@@ -663,6 +794,18 @@ applet_widget_register_stock_callback_dir(AppletWidget *applet,
 						  stock_type,menutext);
 }
 
+/**
+ * applet_widget_unregister_callback_dir:
+ * @applet: #AppletWidget to work on.
+ * @name: path to the menu item.
+ *
+ * Description:  Removes a submenu from the applet's context menu.  Use
+ * this instead of #applet_widget_unregister_callback to remove submenus.
+ * The @name can be, but doesn't have to be terminated with a '/'.  If you
+ * have not removed the subitems of this menu, it will still be shown but
+ * without it's title or icon.  So make sure to first remove any items and
+ * submenus before calling this function.
+ **/
 void
 applet_widget_unregister_callback_dir(AppletWidget *applet, const char *name)
 {
@@ -687,10 +830,19 @@ applet_widget_unregister_callback_dir(AppletWidget *applet, const char *name)
 	g_free(n);
 }
 
+/**
+ * applet_widget_callback_set_sensitive:
+ * @applet: #AppletWidget to work on.
+ * @name: path to the menu item.
+ * @sensitive: whether menu item should be sensitive.
+ *
+ * Description:  Sets the sensitivity of a menu item in the applet's 
+ * context menu.
+ **/
 void
 applet_widget_callback_set_sensitive(AppletWidget *applet,
 				     const char *name,
-				     int sensitive)
+				     gboolean sensitive)
 {
 	CORBA_Environment ev;
 
@@ -843,25 +995,74 @@ applet_widget_new(const char *goad_id)
 
 /**
  * applet_widget_construct:
+ * @applet: #AppletWidget to work on
+ * @goad_id: goad_id of the applet to construct
  *
  * Description: For bindings and subclassing only
- *
  **/
 void
 applet_widget_construct(AppletWidget* applet, const char *goad_id)
 {
 	CustomAppletServant *corbadat;
+	GdkWindow *win;
 	
 	g_return_if_fail(goad_id != NULL);
 
-	applet->corbadat = corbadat = gnome_panel_applet_corba_init(applet,goad_id);
+	applet->_priv->corbadat = corbadat = gnome_panel_applet_corba_init(applet,goad_id);
 
 	if(!corbadat) {
 		g_warning(_("Cannot start CORBA"));
 		return;
 	}
 
+	win = gdk_window_lookup(corbadat->winid);
+
+#if 0
+	/* if local case */
+	if(win) {
+		GdkWindow *temp_window;
+		GdkWindowAttr attributes;
+		gint attributes_mask;
+
+		attributes.window_type = GDK_WINDOW_TEMP;
+
+		attributes.width = 10;
+		attributes.height = 10;
+		attributes.wclass = GDK_INPUT_OUTPUT;
+		attributes.visual = gtk_widget_get_visual (GTK_WIDGET(applet));
+		attributes.colormap = gtk_widget_get_colormap (GTK_WIDGET(applet));
+		attributes.event_mask = 0;
+
+		attributes_mask = GDK_WA_VISUAL | GDK_WA_COLORMAP;
+   
+		temp_window = gdk_window_new(NULL, &attributes,
+					     attributes_mask);
+
+		corbadat->winid = GDK_WINDOW_XWINDOW(temp_window);
+	}
+#endif
 	gtk_plug_construct(GTK_PLUG(applet), corbadat->winid);
+
+	/* after doing all that we just take the socket and put it in limbo */
+	if(win) {
+		GtkWidget *socket;
+		gdk_window_get_user_data (win, (gpointer *)&socket);
+		if(socket) {
+			GtkWidget *temp_window =
+				gtk_window_new(GTK_WINDOW_TOPLEVEL);
+			applet->_priv->ebox = socket->parent;
+			gtk_widget_set_uposition(GTK_WIDGET(temp_window),
+						 gdk_screen_width()+1,
+						 gdk_screen_height()+1);
+			gtk_widget_realize(temp_window);
+			gtk_widget_reparent(GTK_WIDGET(socket),
+					    temp_window);
+			gtk_signal_connect_object(GTK_OBJECT(applet->_priv->ebox),
+						  "destroy",
+						  GTK_SIGNAL_FUNC(gtk_widget_destroy),
+						  GTK_OBJECT(temp_window));
+		}
+	}
 	
 	gtk_signal_connect(GTK_OBJECT(applet),"destroy",
 			   GTK_SIGNAL_FUNC(applet_widget_destroy),
@@ -886,13 +1087,19 @@ applet_widget_get_applet_count(void)
 }
 
 static gboolean
-applet_event(GtkWidget *w,GdkEvent *event,GtkPlug *aw)
+applet_event(GtkWidget *w, GdkEvent *event, AppletWidget *aw)
 {
 	GdkEventButton *bevent = (GdkEventButton *)event;
 	if(event->type == GDK_BUTTON_PRESS && 
 	   (bevent->button == 3 || bevent->button == 2)) {
 		XButtonEvent ev;
 		GtkWidget *wi;
+		GtkPlug *plug = GTK_PLUG(aw);
+
+		/* on local case */
+		if(aw->_priv->ebox)
+			return gtk_widget_event(aw->_priv->ebox, event);
+
 		if((wi = gtk_grab_get_current()))
 			gtk_grab_remove(wi);
 		gdk_pointer_ungrab(GDK_CURRENT_TIME);
@@ -903,7 +1110,7 @@ applet_event(GtkWidget *w,GdkEvent *event,GtkPlug *aw)
 		ev.type = ButtonPress;
 		ev.send_event = True;
 		ev.display = GDK_DISPLAY();
-		ev.window = GDK_WINDOW_XWINDOW(aw->socket_window);
+		ev.window = GDK_WINDOW_XWINDOW(plug->socket_window);
 		ev.subwindow = None;
 		ev.time = bevent->time;
 		ev.x = bevent->x;
@@ -913,9 +1120,16 @@ applet_event(GtkWidget *w,GdkEvent *event,GtkPlug *aw)
 		ev.state = bevent->state;
 		ev.button = bevent->button;
 		ev.same_screen = True;
-		XSendEvent(GDK_DISPLAY(),
-			   GDK_WINDOW_XWINDOW(aw->socket_window),
-			   True,NoEventMask,(XEvent *)&ev);
+		/* in the local case send it to our ebox */
+		if(aw->_priv->ebox && aw->_priv->ebox->window) {
+			XSendEvent(GDK_DISPLAY(),
+				   GDK_WINDOW_XWINDOW(aw->_priv->ebox->window),
+				   True,NoEventMask,(XEvent *)&ev);
+		} else if(plug->socket_window)
+			XSendEvent(GDK_DISPLAY(),
+				   GDK_WINDOW_XWINDOW(plug->socket_window),
+				   True,NoEventMask,(XEvent *)&ev);
+		
 		return TRUE;
 	}
 	return FALSE;
@@ -935,6 +1149,13 @@ bind_applet_events(GtkWidget *widget, gpointer data)
 				       bind_applet_events, data);
 }
 
+static void
+destroy_the_applet(GtkWidget *w, AppletWidget *applet)
+{
+	applet->_priv->ebox = NULL;
+	gtk_widget_destroy(GTK_WIDGET(applet));
+}
+
 /**
  * applet_widget_add_full:
  * @applet: the #AppletWidget to work with
@@ -950,8 +1171,6 @@ bind_applet_events(GtkWidget *widget, gpointer data)
  * special applets and you should use #applet_widget_bind_events on some
  * internal widget if @bind_events was %FALSE.  Normally you'll just want to
  * use #applet_widget_add.
- *
- * Returns:
  **/
 void
 applet_widget_add_full(AppletWidget *applet, GtkWidget *widget,
@@ -964,15 +1183,26 @@ applet_widget_add_full(AppletWidget *applet, GtkWidget *widget,
 	g_return_if_fail(widget != NULL);
 	g_return_if_fail(GTK_IS_WIDGET(widget));
 
-	gtk_container_add(GTK_CONTAINER(applet),widget);
+	if(applet->_priv->ebox) {
+		gtk_container_add(GTK_CONTAINER(applet->_priv->ebox),widget);
+		gtk_signal_connect(GTK_OBJECT(widget), "destroy",
+				   GTK_SIGNAL_FUNC(destroy_the_applet),
+				   applet);
+	} else
+		gtk_container_add(GTK_CONTAINER(applet),widget);
+
 
 	CORBA_exception_init(&ev);
   
 	GNOME_PanelSpot_register_us(CD(applet)->pspot, &ev);
 	CORBA_exception_free(&ev);
 
-	if(bind_events)
-		bind_applet_events(GTK_WIDGET(applet), applet);
+	if(bind_events) {
+		if(applet->_priv->ebox)
+			bind_applet_events(widget, applet);
+		else
+			bind_applet_events(GTK_WIDGET(applet), applet);
+	}
 }
 
 /**
@@ -986,8 +1216,6 @@ applet_widget_add_full(AppletWidget *applet, GtkWidget *widget,
  * this function rather then #gtk_container_add.  If you have already created
  * an applet widget with #applet_widget_new, but need to cancel the loading
  * of the applet, use #applet_widget_abort_load.
- *
- * Returns:
  **/
 void
 applet_widget_add(AppletWidget *applet, GtkWidget *widget)
@@ -1003,13 +1231,20 @@ applet_widget_add(AppletWidget *applet, GtkWidget *widget)
  * Description:  Binds the 2nd and 3rd button clicks over this widget. 
  * Normally this is done during #applet_widget_add, but if you need to
  * bind events over a widget which you added later, use this function.
- *
- * Returns:
  **/
 void
 applet_widget_bind_events(AppletWidget *applet, GtkWidget *widget)
 {
-	bind_applet_events(GTK_WIDGET(applet),widget);
+	g_return_if_fail(applet != NULL);
+	g_return_if_fail(IS_APPLET_WIDGET(applet));
+	g_return_if_fail(widget != NULL);
+	g_return_if_fail(IS_APPLET_WIDGET(widget));
+	
+	if(applet->_priv->ebox && GTK_WIDGET(applet) == widget) {
+		GtkWidget *child = GTK_BIN(applet->_priv->ebox)->child;
+		if(child) bind_applet_events(child, applet);
+	} else
+		bind_applet_events(GTK_WIDGET(widget), applet);
 }
 
 /**
@@ -1020,8 +1255,6 @@ applet_widget_bind_events(AppletWidget *applet, GtkWidget *widget)
  *
  * Description:  Set a tooltip on the @widget that will follow the tooltip
  * setting from the panel configuration.
- *
- * Returns:
  **/
 void
 applet_widget_set_widget_tooltip(AppletWidget *applet,
@@ -1046,8 +1279,6 @@ applet_widget_set_widget_tooltip(AppletWidget *applet,
  *
  * Description:  Set a tooltip on the entire applet that will follow the
  * tooltip setting from the panel configuration.
- *
- * Returns:
  **/
 void
 applet_widget_set_tooltip(AppletWidget *applet, const char *text)
@@ -1067,6 +1298,10 @@ applet_widget_set_tooltip(AppletWidget *applet, const char *text)
  *
  * Description:  Gets the orientation of the panel this widget is on.
  * it can be one of ORIENT_UP, ORIENT_DOWN, ORIENT_LEFT and ORIENT_RIGHT.
+ * This is not the position of the panel, but rather the direction that the
+ * applet should be "reaching out".  So any arrows should for example point
+ * in this direction.  It will be ORIENT_UP or ORIENT_DOWN for horizontal
+ * panels and ORIENT_LEFT or ORIENT_RIGHT for vertical panels
  *
  * Returns:  PanelOrientType enum of the orientation
  **/
@@ -1133,8 +1368,6 @@ applet_widget_get_free_space(AppletWidget *applet)
  * for @enable and bind the change_position signal on the applet.  This signal
  * can be quite CPU/bandwidth consuming so only applets which need it should
  * use it.  By default change_position is not sent.
- *
- * Returns:
  **/
 void
 applet_widget_send_position(AppletWidget *applet, gboolean enable)
@@ -1157,8 +1390,6 @@ applet_widget_send_position(AppletWidget *applet, gboolean enable)
  * with %TRUE for @enable, and then bind the do_draw signal.  Inside that
  * signal you can get an RGB buffer to draw on with #applet_widget_get_rgb_bg.
  * The do_draw signal will only be sent when the RGB truly changed.
- *
- * Returns:
  **/
 void
 applet_widget_send_draw(AppletWidget *applet, gboolean enable)
@@ -1180,11 +1411,9 @@ applet_widget_send_draw(AppletWidget *applet, gboolean enable)
  * @h: pointer to an integer in which the height will be stored
  * @rowstride: pointer to an integer in which the rowstride will be stored
  *
- * Description:  Gets an rgb buffer that you can draw your applet on.  Usefull
+ * Description:  Gets an rgb buffer that you can draw your applet on.  Useful
  * in conjunction with the do_draw signal and the #applet_widget_send_draw
  * method.  The rgb should be freed after use with g_free.
- *
- * Returns:
  **/
 void
 applet_widget_get_rgb_bg(AppletWidget *applet, guchar **rgb,
@@ -1303,8 +1532,6 @@ applet_widget_init(const char *app_id,
  * applet_widget_gtk_main:
  *
  * Description: Run the main loop, just like #gtk_main
- *
- * Returns:
  **/
 void
 applet_widget_gtk_main(void)
@@ -1316,8 +1543,6 @@ applet_widget_gtk_main(void)
  * applet_widget_gtk_main_quit:
  *
  * Description: Quit the main loop, just like #gtk_main_quit
- *
- * Returns:
  **/
 void
 applet_widget_gtk_main_quit (void)
@@ -1331,8 +1556,6 @@ applet_widget_gtk_main_quit (void)
  * Description: Trigger 'Log out' on the panel.  This shouldn't be
  * used in normal applets, as it is not normal for applets to trigger
  * a logout.
- *
- * Returns:
  **/
 void
 applet_widget_panel_quit (void)
@@ -1348,12 +1571,10 @@ applet_widget_panel_quit (void)
  * applet_widget_queue_resize:
  * @applet: #AppletWidget to work on
  *
- * Description:  For shared library applets this calls
- * #gtk_widget_queue_resize on the socket, for external applets this
- * just calls this on the #AppletWidget itself, but in both cases
- * it forces a resize of the socket on the panel
- *
- * Returns:
+ * Description:  For shared library applets this calls #gtk_widget_queue_resize
+ * on the internal panel eventbox, for external applets this just calls this on
+ * the #AppletWidget itself, but in both cases it forces a resize of the socket
+ * on the panel
  **/
 void
 applet_widget_queue_resize(AppletWidget *applet)
@@ -1365,17 +1586,10 @@ applet_widget_queue_resize(AppletWidget *applet)
 
 	plug = GTK_PLUG(applet);
 
-	/* XXX: hackaround to broken gtkplug/gtksocket, we must manually
-	   queue resize on the socket as the plug does not have a parent */
-	if(plug->same_app && plug->socket_window) {
-		GtkWidget *socket;
-		gdk_window_get_user_data (plug->socket_window,
-					  (gpointer *)&socket);
-		if(socket)
-			gtk_widget_queue_resize(socket);
-	} else {
+	if(applet->_priv->ebox)
+		gtk_widget_queue_resize(applet->_priv->ebox);
+	else
 		gtk_widget_queue_resize(GTK_WIDGET(applet));
-	}
 }
 
 static void
@@ -1385,9 +1599,9 @@ server_applet_change_orient(PortableServer_Servant _servant,
 {
 	CustomAppletServant *servant = (CustomAppletServant *)_servant;
 	servant->appwidget->orient = orient;
-	if(servant->appwidget->frozen_level>0) {
-		servant->appwidget->frozen_got_orient = TRUE;
-		servant->appwidget->frozen_size = (GNOME_Panel_OrientType)orient;
+	if(servant->appwidget->_priv->frozen_level>0) {
+		servant->appwidget->_priv->frozen_got_orient = TRUE;
+		servant->appwidget->_priv->frozen_size = (GNOME_Panel_OrientType)orient;
 	} else {
 		gtk_signal_emit(GTK_OBJECT(servant->appwidget),
 				applet_widget_signals[CHANGE_ORIENT_SIGNAL],
@@ -1402,9 +1616,9 @@ server_applet_change_size(PortableServer_Servant _servant,
 {
 	CustomAppletServant *servant = (CustomAppletServant *)_servant;
 	servant->appwidget->size = size;
-	if(servant->appwidget->frozen_level>0) {
-		servant->appwidget->frozen_got_size = TRUE;
-		servant->appwidget->frozen_size = size;
+	if(servant->appwidget->_priv->frozen_level>0) {
+		servant->appwidget->_priv->frozen_got_size = TRUE;
+		servant->appwidget->_priv->frozen_size = size;
 	} else {
 		gtk_signal_emit(GTK_OBJECT(servant->appwidget),
 				applet_widget_signals[CHANGE_PIXEL_SIZE_SIGNAL],
@@ -1509,15 +1723,15 @@ server_applet_back_change(PortableServer_Servant _servant,
 		break;
 	}
 
-	if(servant->appwidget->frozen_level>0) {
-		servant->appwidget->frozen_got_back = TRUE;
-		servant->appwidget->frozen_back_type = (GNOME_Panel_BackType)backing->_d;
-		g_free(servant->appwidget->frozen_back_pixmap);
-		if(servant->appwidget->frozen_back_pixmap)
-			servant->appwidget->frozen_back_pixmap = g_strdup(pptr);
+	if(servant->appwidget->_priv->frozen_level>0) {
+		servant->appwidget->_priv->frozen_got_back = TRUE;
+		servant->appwidget->_priv->frozen_back_type = (GNOME_Panel_BackType)backing->_d;
+		g_free(servant->appwidget->_priv->frozen_back_pixmap);
+		if(servant->appwidget->_priv->frozen_back_pixmap)
+			servant->appwidget->_priv->frozen_back_pixmap = g_strdup(pptr);
 		else
-			servant->appwidget->frozen_back_pixmap = NULL;
-		servant->appwidget->frozen_back_color = color;
+			servant->appwidget->_priv->frozen_back_pixmap = NULL;
+		servant->appwidget->_priv->frozen_back_color = color;
 	} else {
 		gtk_signal_emit(GTK_OBJECT(servant->appwidget),
 				applet_widget_signals[BACK_CHANGE_SIGNAL],
@@ -1562,10 +1776,10 @@ server_applet_change_position(PortableServer_Servant _servant,
 			      CORBA_Environment *ev)
 {
 	CustomAppletServant *servant = (CustomAppletServant *)_servant;
-	if(servant->appwidget->frozen_level>0) {
-		servant->appwidget->frozen_got_position = TRUE;
-		servant->appwidget->frozen_position_x = x;
-		servant->appwidget->frozen_position_y = y;
+	if(servant->appwidget->_priv->frozen_level>0) {
+		servant->appwidget->_priv->frozen_got_position = TRUE;
+		servant->appwidget->_priv->frozen_position_x = x;
+		servant->appwidget->_priv->frozen_position_y = y;
 	} else {
 		gtk_signal_emit(GTK_OBJECT(servant->appwidget),
 				applet_widget_signals[CHANGE_POSITION_SIGNAL],
@@ -1587,7 +1801,7 @@ server_applet_freeze_changes(PortableServer_Servant _servant,
 			     CORBA_Environment *ev)
 {
 	CustomAppletServant *servant = (CustomAppletServant *)_servant;
-	servant->appwidget->frozen_level++;
+	servant->appwidget->_priv->frozen_level++;
 }
 
 static void
@@ -1595,39 +1809,39 @@ server_applet_thaw_changes(PortableServer_Servant _servant,
 			   CORBA_Environment *ev)
 {
 	CustomAppletServant *servant = (CustomAppletServant *)_servant;
-	if(servant->appwidget->frozen_level>0)
-		servant->appwidget->frozen_level--;
+	if(servant->appwidget->_priv->frozen_level>0)
+		servant->appwidget->_priv->frozen_level--;
 	
-	if(servant->appwidget->frozen_level>0)
+	if(servant->appwidget->_priv->frozen_level>0)
 		return;
 
-	if(servant->appwidget->frozen_got_orient) {
-		servant->appwidget->frozen_got_orient = FALSE;
+	if(servant->appwidget->_priv->frozen_got_orient) {
+		servant->appwidget->_priv->frozen_got_orient = FALSE;
 		gtk_signal_emit(GTK_OBJECT(servant->appwidget),
 				applet_widget_signals[CHANGE_ORIENT_SIGNAL],
-				servant->appwidget->frozen_orient);
+				servant->appwidget->_priv->frozen_orient);
 	}
-	if(servant->appwidget->frozen_got_size) {
-		servant->appwidget->frozen_got_size = FALSE;
+	if(servant->appwidget->_priv->frozen_got_size) {
+		servant->appwidget->_priv->frozen_got_size = FALSE;
 		gtk_signal_emit(GTK_OBJECT(servant->appwidget),
 				applet_widget_signals[CHANGE_PIXEL_SIZE_SIGNAL],
-				servant->appwidget->frozen_size);
+				servant->appwidget->_priv->frozen_size);
 	}
-	if(servant->appwidget->frozen_got_back) {
-		servant->appwidget->frozen_got_back = FALSE;
+	if(servant->appwidget->_priv->frozen_got_back) {
+		servant->appwidget->_priv->frozen_got_back = FALSE;
 		gtk_signal_emit(GTK_OBJECT(servant->appwidget),
 				applet_widget_signals[BACK_CHANGE_SIGNAL],
-				servant->appwidget->frozen_back_type,
-				servant->appwidget->frozen_back_pixmap,
-				&servant->appwidget->frozen_back_color);
-		g_free(servant->appwidget->frozen_back_pixmap);
+				servant->appwidget->_priv->frozen_back_type,
+				servant->appwidget->_priv->frozen_back_pixmap,
+				&servant->appwidget->_priv->frozen_back_color);
+		g_free(servant->appwidget->_priv->frozen_back_pixmap);
 	}
-	if(servant->appwidget->frozen_got_position) {
-		servant->appwidget->frozen_got_position = FALSE;
+	if(servant->appwidget->_priv->frozen_got_position) {
+		servant->appwidget->_priv->frozen_got_position = FALSE;
 		gtk_signal_emit(GTK_OBJECT(servant->appwidget),
 				applet_widget_signals[CHANGE_POSITION_SIGNAL],
-				servant->appwidget->frozen_position_x,
-				servant->appwidget->frozen_position_y);
+				servant->appwidget->_priv->frozen_position_x,
+				servant->appwidget->_priv->frozen_position_y);
 	}
 }
 
@@ -1671,10 +1885,17 @@ orb_remove_connection(GIOPConnection *cnx)
 /* Used by shlib applets */
 /**
  * applet_widget_corba_activate:
+ * @applet: widget to embed.
+ * @poa: the POA to use.
+ * @goad_id: the GOAD ID string for the applet.
+ * @params: params passed when the applet is activated.
+ * @impl_ptr:
+ * @ev: CORBA environment to use for errors.
  *
- * Description:
+ * Description: Duplicates the applet's CORBA object.  This should
+ * be called when a shared library applet is activated.
  *
- * Returns:
+ * Returns: the duplication CORBA object to use.
  **/
 CORBA_Object
 applet_widget_corba_activate(GtkWidget *applet,
@@ -1689,10 +1910,12 @@ applet_widget_corba_activate(GtkWidget *applet,
 
 /**
  * applet_widget_corba_deactivate:
- *
+ * @poa: the POA to use.
+ * @goad_id: the GOAD ID of the applet.
+ * @impl_ptr:
+ * @ev: CORBA environment to use for errors.
+ * 
  * Description:
- *
- * Returns:
  **/
 void
 applet_widget_corba_deactivate(PortableServer_POA poa,
@@ -1759,10 +1982,12 @@ static POA_GNOME_GenericFactory__vepv applet_factory_vepv = {
 
 /**
  * applet_factory_new:
+ * @goad_id: GOAD ID of the factory to be registered.
+ * @qfunc: #AppletFactoryQuerier to determine whether an applet with
+ * a specified GOAD ID can be created.
+ * @afunc: #AppletFactoryActivator to activate a specified GOAD ID.
  *
- * Description:
- *
- * Returns:
+ * Description: create a new applet factory.
  **/
 void applet_factory_new(const char *goad_id, AppletFactoryQuerier qfunc,
 			AppletFactoryActivator afunc)
