@@ -791,6 +791,19 @@ basep_widget_destroy (BasePWidget *basep)
 		gtk_timeout_remove (basep->leave_notify_timer_tag);
 }	
 
+static void
+reparent_button_widgets(GtkWidget *w, gpointer data)
+{
+	GdkWindow *newwin = data;
+	if(IS_BUTTON_WIDGET(w)) {
+		ButtonWidget *button = BUTTON_WIDGET(w);
+		/* we can just reparent them all to 0,0 as the next thing
+		 * that will happen is a queue_resize and on size allocate
+		 * they will be put into their proper place */
+		gdk_window_reparent(button->event_window, newwin, 0, 0);
+	}
+}
+
 void
 basep_widget_redo_window(BasePWidget *basep)
 {
@@ -847,7 +860,14 @@ basep_widget_redo_window(BasePWidget *basep)
 	newwin = gdk_window_new(NULL, &attributes, attributes_mask);
 	gdk_window_set_user_data(newwin, window);
 
+	/* reparent our main panel window */
 	gdk_window_reparent(basep->ebox->window, newwin, 0, 0);
+	/* reparent all the base event windows as they are also children of
+	 * the basep */
+	gtk_container_foreach(GTK_CONTAINER(basep->panel),
+			      reparent_button_widgets,
+			      newwin);
+
 
 	widget->window = newwin;
 
@@ -863,6 +883,8 @@ basep_widget_redo_window(BasePWidget *basep)
 
 	basep_widget_update_winhints (basep);
 
+	gtk_drag_dest_set (widget, 0, NULL, 0, 0);
+
 	gtk_widget_map(widget);
 }
 
@@ -982,6 +1004,7 @@ basep_widget_update_winhints (BasePWidget *basep)
 	
 	switch (basep->state) {
 	case BASEP_SHOWN:
+	case BASEP_MOVING:
 		gnome_win_hints_set_hints (w, GNOME_PANEL_HINTS |
 					   WIN_HINTS_DO_NOT_COVER);
 		gnome_win_hints_set_layer (w, global_config.keep_bottom
@@ -1399,6 +1422,7 @@ basep_widget_explicit_hide (BasePWidget *basep, BasePState state)
 			h : w;
 		
 		basep->state = BASEP_MOVING;
+		basep_widget_update_winhints (basep);
 		basep_widget_do_hiding (basep, hide_orient,
 					size, pw_explicit_step);
 	}
@@ -1441,7 +1465,7 @@ basep_widget_explicit_show (BasePWidget *basep)
 			h : w;
 
 		basep->state = BASEP_MOVING;
-		
+		basep_widget_update_winhints (basep);
 		basep_widget_do_showing (basep, hide_orient,
 					 size, pw_explicit_step);
 	}
@@ -1486,7 +1510,7 @@ basep_widget_autoshow (BasePWidget *basep)
 			h : w;
 
 		basep->state = BASEP_MOVING;
-
+		basep_widget_update_winhints (basep);
 		basep_widget_do_showing (basep,
 					 hide_orient,
 					 size,
@@ -1564,7 +1588,7 @@ basep_widget_autohide (gpointer data)
 			? h : w;
 
 		basep->state = BASEP_MOVING;
-
+		basep_widget_update_winhints (basep);
 		basep_widget_do_hiding (basep,
 					hide_orient,
 					size,
