@@ -425,7 +425,9 @@ save_applet_configuration(AppletInfo *info)
 		gnome_config_set_string("id", STATUS_ID);
 		break;
 	default:
-		g_assert_not_reached();
+		g_warning ("Unknown applet type encountered: %d; ignoring.",
+			   info->type);
+		break;
 	}
 	gnome_config_set_int("position", ad->pos);
 	gnome_config_set_int("panel", panel_num);
@@ -730,9 +732,9 @@ load_default_applets1(PanelWidget *panel)
 {
 	char *def_launchers[] =
 	      { "gnome/apps/gnome-help.desktop",
-		"gnome/apps/Utilities/gnome-terminal.desktop",
+		"gnome/apps/System/gnome-terminal.desktop",
 		"gnome/apps/Settings/gnomecc.desktop",
-		"gnome/apps/Applications/Netscape.desktop",
+		"gnome/apps/Internet/Netscape.desktop",
 		NULL };
 	int i;
 	char *p;
@@ -880,7 +882,7 @@ init_user_applets(void)
 						  MAIN_MENU_USER_SUB |
 						  MAIN_MENU_APPLETS_SUB |
 						  MAIN_MENU_PANEL_SUB |
-						  MAIN_MENU_DESKTOP_SUB));
+						  MAIN_MENU_DESKTOP));
 			flags = gnome_config_get_int(s);
 			g_free(s);
 
@@ -916,7 +918,7 @@ init_user_applets(void)
 					flags &=~ MAIN_MENU_USER;
 				if(flags&MAIN_MENU_REDHAT &&
 				   flags&MAIN_MENU_REDHAT_SUB)
-					flags &=~ MAIN_MENU_USER;
+					flags &=~ MAIN_MENU_REDHAT;
 				if(flags&MAIN_MENU_DEBIAN &&
 				   flags&MAIN_MENU_DEBIAN_SUB)
 					flags &=~ MAIN_MENU_DEBIAN;
@@ -925,7 +927,7 @@ init_user_applets(void)
 					flags &=~ MAIN_MENU_KDE;
 				flags |= MAIN_MENU_APPLETS_SUB |
 					MAIN_MENU_PANEL_SUB |
-					MAIN_MENU_DESKTOP_SUB;
+					MAIN_MENU_DESKTOP;
 			}
 
 			load_menu_applet(params, flags, panel, pos, TRUE);
@@ -1202,7 +1204,8 @@ init_user_panels(void)
 			break;
 		}
 		default:
-			g_assert_not_reached ();
+			panel = NULL;
+			g_warning ("Unkown panel type: %d; ignoring.", type);
 			break;
 		}
 
@@ -1239,7 +1242,7 @@ load_up_globals(void)
 		gnome_config_get_bool("show_dot_buttons=FALSE");
 
 	global_config.hungry_menus =
-		gnome_config_get_bool("hungry_menus=TRUE");
+		gnome_config_get_bool("memory_hungry_menus=FALSE");
 
 	global_config.use_large_icons =
 		gnome_config_get_bool(gdk_screen_height () > 768 
@@ -1275,16 +1278,18 @@ load_up_globals(void)
 
 	global_config.keys_enabled=gnome_config_get_bool("keys_enabled=TRUE");
 
-	g_string_sprintf(buf,"menu_keycode=%d", XK_RIGHT_MENU);
-	global_config.menu_keycode=gnome_config_get_int(buf->str);
+	g_free(global_config.menu_key);
+	global_config.menu_key = gnome_config_get_string("menu_key=Menu");
+	convert_string_to_keysym_state(global_config.menu_key,
+				       &global_config.menu_keysym,
+				       &global_config.menu_state);
 
-	global_config.menu_state=gnome_config_get_int("menu_state=0");
+	g_free(global_config.run_key);
+	global_config.run_key = gnome_config_get_string("run_key=Control-Mod1-r");
+	convert_string_to_keysym_state(global_config.run_key,
+				       &global_config.run_keysym,
+				       &global_config.run_state);
 
-	g_string_sprintf(buf,"run_keycode=%d", XK_r);
-	global_config.run_keycode=gnome_config_get_int(buf->str);
-
-	global_config.run_state=gnome_config_get_int("run_state=0");
-	
 	global_config.applet_padding=gnome_config_get_int("applet_padding=3");
 
 	global_config.autoraise = gnome_config_get_bool("autoraise=TRUE");
@@ -1296,6 +1301,7 @@ load_up_globals(void)
 	global_config.hide_panel_frame = gnome_config_get_bool("hide_panel_frame=FALSE");
 	global_config.tile_when_over = gnome_config_get_bool("tile_when_over=FALSE");
 	global_config.saturate_when_over = gnome_config_get_bool("saturate_when_over=TRUE");
+	global_config.confirm_panel_remove = gnome_config_get_bool("confirm_panel_remove=TRUE");
 	
 	g_string_sprintf (buf, "menu_flags=%d", get_default_menu_flags ());
 	global_config.menu_flags = gnome_config_get_int (buf->str);
@@ -1354,7 +1360,7 @@ write_global_config(void)
 			      global_config.tooltips_enabled);
 	gnome_config_set_bool("show_dot_buttons",
 			      global_config.show_dot_buttons);
-	gnome_config_set_bool("hungry_menus",
+	gnome_config_set_bool("memory_hungry_menus",
 			      global_config.hungry_menus);
 	gnome_config_set_bool("use_large_icons",
 			      global_config.use_large_icons);
@@ -1378,12 +1384,12 @@ write_global_config(void)
 			      global_config.tile_when_over);
 	gnome_config_set_bool("saturate_when_over",
 			      global_config.saturate_when_over);
+	gnome_config_set_bool("confirm_panel_remove",
+			      global_config.confirm_panel_remove);
 	gnome_config_set_int("menu_flags", global_config.menu_flags);
 	gnome_config_set_bool("keys_enabled", global_config.keys_enabled);
-	gnome_config_set_int("menu_keycode", global_config.menu_keycode);
-	gnome_config_set_int("menu_state", global_config.menu_state);
-	gnome_config_set_int("run_keycode", global_config.run_keycode);
-	gnome_config_set_int("run_sate", global_config.run_state);
+	gnome_config_set_string("menu_key", global_config.menu_key);
+	gnome_config_set_string("run_key", global_config.run_key);
 			     
 	buf = g_string_new(NULL);
 	for(i=0;i<LAST_TILE;i++) {
@@ -1442,7 +1448,7 @@ convert_write_config(void)
 			      global_config.tooltips_enabled);
 	gnome_config_set_bool("show_dot_buttons",
 			      global_config.show_dot_buttons);
-	gnome_config_set_bool("hungry_menus",
+	gnome_config_set_bool("memory_hungry_menus",
 			      global_config.hungry_menus);
 	gnome_config_set_bool("off_panel_popups",
 			      global_config.off_panel_popups);
@@ -1462,8 +1468,6 @@ convert_write_config(void)
 			      global_config.hide_panel_frame);
 	gnome_config_set_bool("tile_when_over",
 			      global_config.tile_when_over);
-	gnome_config_set_bool("saturate_when_over",
-			      global_config.saturate_when_over);
 	buf = g_string_new(NULL);
 	for(i=0;i<LAST_TILE;i++) {
 		g_string_sprintf(buf,"tiles_enabled_%d",i);
@@ -1512,8 +1516,12 @@ convert_read_old_config(void)
 	global_config.show_dot_buttons =
 		gnome_config_get_bool("show_dot_buttons=FALSE");
 
+	/*
 	global_config.hungry_menus =
 		gnome_config_get_bool("hungry_menus=TRUE");
+		*/
+	/* we default to FALSE now and want everything to go to false */
+	global_config.hungry_menus = FALSE;
 
 	global_config.off_panel_popups =
 		gnome_config_get_bool("off_panel_popups=TRUE");
