@@ -17,7 +17,7 @@ struct _StatusApplet {
 	GtkWidget *frame;
 	GtkWidget *handle; /*a gtk handlebox but one that doesn't undock*/
 	PanelOrientation orient;
-	PanelSizeType size;
+	int size;
 	AppletInfo *info;
 };
 
@@ -31,16 +31,20 @@ struct _StatusSpot {
 	gulong wid;
 };
 
+void status_applet_create_offscreen(void);
+
 StatusSpot *new_status_spot(void);
 void status_spot_remove(StatusSpot *ss, gboolean destroy_socket);
 /*kill all status spots*/
 void status_spot_remove_all(void);
 
 /*returns TRUE if it could create an applet, FALSE if one already exists*/
-int load_status_applet(PanelWidget *panel, int pos);
+gboolean load_status_applet(PanelWidget *panel, int pos, gboolean exactpos);
 void status_applet_update(StatusApplet *s);
 void status_applet_put_offscreen(StatusApplet *s);
 
+StatusSpot * status_applet_get_ss(guint32 winid);
+
 /*inhibit adding and updating for the purpose of quitting*/
 extern int status_inhibit;
 
